import {
  gradientStartColor,
  publicationColor,
  publicationPalette, publicationIndicatorsPalette, goldGreenIndicatorsPalette
} from '../../../../chart-palettes';
import { Component, OnInit } from '@angular/core';
import { environment } from '../../../../../environments/environment';
import { DomSanitizer, SafeResourceUrl} from '@angular/platform-browser';
import { TreemapHighchartsData } from '../../../../domain/treemap-highcharts-data';
import { DataHandlerService } from '../../../../services/data-handler.service';
import { DataService } from '../../../../services/data.service';
import { ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-country-os-publications-indicators',
  templateUrl: './country-os-publications-indicators.component.html',
})

export class CountryOSPublicationsIndicatorsComponent implements OnInit {

  private chartsURL = environment.API_ENDPOINT + 'chart?json=';
  private profileName = environment.profileName;

  indicator: string;

  private publicationPalette = publicationPalette;
  private publicationIndicatorsPalette = publicationIndicatorsPalette;
  private goldGreenIndicatorsPalette = goldGreenIndicatorsPalette;

  publicationColor = publicationColor;
  gradientStartColor = gradientStartColor;

  countryCode: string;

  publicationsWithLicenceTimeline: SafeResourceUrl;
  publicationsWithCCLicenceTimeline: SafeResourceUrl;
  publicationsWithPIDTimeline: SafeResourceUrl;
  publicationsWithAbstractTimeline: SafeResourceUrl;
  publicationsWithGoldGreenTimeline: SafeResourceUrl;

  publicationsWithPIDGroupByView = 'datasource';
  publicationsWithPIDByDatasourceChartURL: SafeResourceUrl;
  publicationsWithPIDByOrganizationChartURL: SafeResourceUrl;

  publicationsWithLicenceGroupByView = 'datasource';
  publicationsWithLicenceByDatasourceChartURL: SafeResourceUrl;
  publicationsWithLicenceByOrganizationChartURL: SafeResourceUrl;

  publicationsWithCCLicenceGroupByView = 'datasource';
  publicationsWithCCLicenceByDatasourceChartURL: SafeResourceUrl;
  publicationsWithCCLicenceByOrganizationChartURL: SafeResourceUrl;

  publicationsWithAbstractGroupByView = 'datasource';
  publicationsWithAbstractByDatasourceChartURL: SafeResourceUrl;
  publicationsWithAbstractByOrganizationChartURL: SafeResourceUrl;

  publicationsWithGoldGreenGroupByView = 'country';
  publicationsWithGoldGreenByDatasourceChartURL: SafeResourceUrl;
  publicationsWithGoldGreenByOrganizationChartURL: SafeResourceUrl;
  publicationsWithGoldGreenByFunderChartURL: SafeResourceUrl;

  publicationsWithPIDByFunderData: TreemapHighchartsData[];
  publicationsWithLicenceByFunderData: TreemapHighchartsData[];
  publicationsWithCCLicenceByFunderData: TreemapHighchartsData[];
  publicationsWithAbstractByFunderData: TreemapHighchartsData[];


  constructor(private dataService: DataService,
              private dataHandlerService: DataHandlerService,
              private route: ActivatedRoute,
              private sanitizer: DomSanitizer) { }

  ngOnInit(): void {

    this.route.params.subscribe(params => {

      this.indicator = params['indicator'];
    });

    this.route.parent.parent.parent.parent.parent.params.subscribe(params => {

      this.countryCode = params['countryCode'];

      this.publicationsWithPIDTimeline = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with PID","type":"column","query":{"name":"new.oso.publications.pid_timeline.peer_reviewed.affiliated.country","parameters":["${this.countryCode}",1],"profile":"${this.profileName}"}},{"name":"without PID","type":"column","query":{"name":"new.oso.publications.pid_timeline.peer_reviewed.affiliated.country","parameters":["${this.countryCode}",0],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with PID","align":"left","margin":50},"subtitle":{"text":"over time","align":"left","margin":50},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
      this.publicationsWithLicenceTimeline = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with licence","type":"column","query":{"name":"new.oso.publications.licence_timeline.peer_reviewed.affiliated.country","parameters":["${this.countryCode}",1],"profile":"${this.profileName}"}},{"name":"without licence","type":"column","query":{"name":"new.oso.publications.licence_timeline.peer_reviewed.affiliated.country","parameters":["${this.countryCode}",0],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with licence","align":"left","margin":50},"subtitle":{"text":"over time","align":"left","margin":50},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
      this.publicationsWithCCLicenceTimeline = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with CC licence","type":"column","query":{"name":"new.oso.publications.cc_licence_timeline.peer_reviewed.affiliated.country","parameters":["${this.countryCode}",1],"profile":"${this.profileName}"}},{"name":"without CC licence","type":"column","query":{"name":"new.oso.publications.cc_licence_timeline.peer_reviewed.affiliated.country","parameters":["${this.countryCode}",0],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with CC licence","align":"left","margin":50},"subtitle":{"text":"over time","align":"left","margin":50},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
      this.publicationsWithAbstractTimeline = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with abstract","type":"column","query":{"name":"new.oso.publications.abstract_timeline.peer_reviewed.affiliated.country","parameters":["${this.countryCode}",1],"profile":"${this.profileName}"}},{"name":"without abstract","type":"column","query":{"name":"new.oso.publications.abstract_timeline.peer_reviewed.affiliated.country","parameters":["${this.countryCode}",0],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with abstract","align":"left","margin":50},"subtitle":{"text":"over time","align":"left","margin":50},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
      this.publicationsWithGoldGreenTimeline = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"Gold OA only","type":"column","query":{"name":"new.oso.publications.green_gold_timeline.peer_reviewed.affiliated.country","parameters":[0,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"both Gold & Green OA","type":"column","query":{"name":"new.oso.publications.green_gold_timeline.peer_reviewed.affiliated.country","parameters":[1,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"Green OA only","type":"column","query":{"name":"new.oso.publications.green_gold_timeline.peer_reviewed.affiliated.country","parameters":[1,0,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"neither","type":"column","query":{"name":"new.oso.publications.green_gold_timeline.peer_reviewed.affiliated.country","parameters":[0,0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Gold vs Green Open Access publications","align":"left","margin":50},"subtitle":{"text":"over time","align":"left","margin":50},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.goldGreenIndicatorsPalette.join('","')}\"]}}`));

      this.publicationsWithPIDByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with PID","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
      this.publicationsWithLicenceByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with licence","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
      this.publicationsWithCCLicenceByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with CC licence","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
      this.publicationsWithAbstractByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with abstract","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
      this.publicationsWithGoldGreenByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"Gold OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[0,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"both Gold & Green OA","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[1,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"Green OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[1,0,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"neither","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[0,0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Gold vs Green Open Access publications","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.goldGreenIndicatorsPalette.join('","')}\"]}}`));


      this.dataService.getFundersResultsByPublicationsForIndicatorForCountry('pid', this.countryCode).subscribe(
        rawData => {
          this.publicationsWithPIDByFunderData = this.dataHandlerService.convertRawDataToTreemapHighchartsData(rawData);
        }, error => {
          console.log(error);
        }
      );

      this.dataService.getFundersResultsByPublicationsForIndicatorForCountry('licence', this.countryCode).subscribe(
        rawData => {
          this.publicationsWithLicenceByFunderData = this.dataHandlerService.convertRawDataToTreemapHighchartsData(rawData);
        }, error => {
          console.log(error);
        }
      );

      this.dataService.getFundersResultsByPublicationsForIndicatorForCountry('cc_licence', this.countryCode).subscribe(
        rawData => {
          this.publicationsWithCCLicenceByFunderData = this.dataHandlerService.convertRawDataToTreemapHighchartsData(rawData);
        }, error => {
          console.log(error);
        }
      );

      this.dataService.getFundersResultsByPublicationsForIndicatorForCountry('abstract', this.countryCode).subscribe(
        rawData => {
          this.publicationsWithAbstractByFunderData = this.dataHandlerService.convertRawDataToTreemapHighchartsData(rawData);
        }, error => {
          console.log(error);
        }
      );

    });

  }

  getPublicationsWithPIDGroupBy(contentSelection: string): void {
    this.publicationsWithPIDGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithPIDByDatasourceChartURL) {
      this.publicationsWithPIDByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with PID","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithPIDByOrganizationChartURL) {
      this.publicationsWithPIDByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.byorganization.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.byorganization.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with PID","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    }
  }

  getPublicationsWithPIDGroupByMobile(contentSelection: string): void {
    this.publicationsWithPIDGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithPIDByDatasourceChartURL) {
      this.publicationsWithPIDByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with PID","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithPIDByOrganizationChartURL) {
      this.publicationsWithPIDByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.byorganization.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without PID","type":"bar","query":{"name":"new.oso.publications.pid.peer_reviewed.affiliated.byorganization.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with PID","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    }
  }

  getPublicationsWithLicenceGroupBy(contentSelection: string): void {
    this.publicationsWithLicenceGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithLicenceByDatasourceChartURL) {
      this.publicationsWithLicenceByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with licence","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithLicenceByOrganizationChartURL) {
      this.publicationsWithLicenceByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.byorganization.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.byorganization.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with licence","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    }
  }

  getPublicationsWithLicenceGroupByMobile(contentSelection: string): void {
    this.publicationsWithLicenceGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithLicenceByDatasourceChartURL) {
      this.publicationsWithLicenceByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with licence","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithLicenceByOrganizationChartURL) {
      this.publicationsWithLicenceByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.byorganization.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without licence","type":"bar","query":{"name":"new.oso.publications.licence.peer_reviewed.affiliated.byorganization.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with licence","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    }
  }

  getPublicationsWithCCLicenceGroupBy(contentSelection: string): void {
    this.publicationsWithCCLicenceGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithCCLicenceByDatasourceChartURL) {
      this.publicationsWithCCLicenceByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with CC licence","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithCCLicenceByOrganizationChartURL) {
      this.publicationsWithCCLicenceByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.byorganization.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.byorganization.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with CC licence","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    }
  }

  getPublicationsWithCCLicenceGroupByMobile(contentSelection: string): void {
    this.publicationsWithCCLicenceGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithCCLicenceByDatasourceChartURL) {
      this.publicationsWithCCLicenceByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with CC licence","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithCCLicenceByOrganizationChartURL) {
      this.publicationsWithCCLicenceByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.byorganization.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without CC licence","type":"bar","query":{"name":"new.oso.publications.cc_licence.peer_reviewed.affiliated.byorganization.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with CC licence","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    }
  }

  getPublicationsWithAbstractGroupBy(contentSelection: string): void {
    this.publicationsWithAbstractGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithAbstractByDatasourceChartURL) {
      this.publicationsWithAbstractByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with abstract","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithAbstractByOrganizationChartURL) {
      this.publicationsWithAbstractByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.byorganization.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.byorganization.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with abstract","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    }
  }

  getPublicationsWithAbstractGroupByMobile(contentSelection: string): void {
    this.publicationsWithAbstractGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithAbstractByDatasourceChartURL) {
      this.publicationsWithAbstractByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.bydatasource.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.bydatasource.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with abstract","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithAbstractByOrganizationChartURL) {
      this.publicationsWithAbstractByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"with abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.byorganization.country","parameters":[1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"without abstract","type":"bar","query":{"name":"new.oso.publications.abstract.peer_reviewed.affiliated.byorganization.country","parameters":[0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Open Access publications with abstract","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.publicationIndicatorsPalette.join('","')}\"]}}`));
    }
  }

  getPublicationsWithGoldGreenGroupBy(contentSelection: string): void {
    this.publicationsWithGoldGreenGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithGoldGreenByDatasourceChartURL) {
      this.publicationsWithGoldGreenByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"Gold OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[0,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"both Gold & Green OA","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[1,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"Green OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[1,0,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"neither","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[0,0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Gold vs Green Open Access publications","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.goldGreenIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithGoldGreenByOrganizationChartURL) {
      this.publicationsWithGoldGreenByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"Gold OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byorganization.country","parameters":[0,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"both Gold & Green OA","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byorganization.country","parameters":[1,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"Green OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byorganization.country","parameters":[1,0,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"neither","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byorganization.country","parameters":[0,0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Gold vs Green Open Access publications","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.goldGreenIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'funder' && !this.publicationsWithGoldGreenByFunderChartURL) {
      this.publicationsWithGoldGreenByFunderChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"Gold OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byfunder.country","parameters":[0,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"both Gold & Green OA","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byfunder.country","parameters":[1,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"Green OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byfunder.country","parameters":[1,0,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"neither","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byfunder.country","parameters":[0,0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Gold vs Green Open Access publications","align":"left","margin":50},"subtitle":{"text":"by funder (top funders)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.goldGreenIndicatorsPalette.join('","')}\"]}}`));
    }
  }

  getPublicationsWithGoldGreenGroupByMobile(contentSelection: string): void {
    this.publicationsWithGoldGreenGroupByView = contentSelection;
    if (contentSelection === 'datasource' && !this.publicationsWithGoldGreenByDatasourceChartURL) {
      this.publicationsWithGoldGreenByDatasourceChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"Gold OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[0,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"both Gold & Green OA","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[1,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"Green OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[1,0,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"neither","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.bydatasource.country","parameters":[0,0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Gold vs Green Open Access publications","align":"left","margin":50},"subtitle":{"text":"by datasource (top datasources)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.goldGreenIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'organization' && !this.publicationsWithGoldGreenByOrganizationChartURL) {
      this.publicationsWithGoldGreenByOrganizationChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"Gold OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byorganization.country","parameters":[0,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"both Gold & Green OA","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byorganization.country","parameters":[1,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"Green OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byorganization.country","parameters":[1,0,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"neither","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byorganization.country","parameters":[0,0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Gold vs Green Open Access publications","align":"left","margin":50},"subtitle":{"text":"by organization (top organizations)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.goldGreenIndicatorsPalette.join('","')}\"]}}`));
    } else if (contentSelection === 'funder' && !this.publicationsWithGoldGreenByFunderChartURL) {
      this.publicationsWithGoldGreenByFunderChartURL = this.sanitizer.bypassSecurityTrustResourceUrl(this.chartsURL + encodeURIComponent(`{"library":"HighCharts","chartDescription":{"queries":[{"name":"Gold OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byfunder.country","parameters":[0,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"both Gold & Green OA","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byfunder.country","parameters":[1,1,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"Green OA only","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byfunder.country","parameters":[1,0,"${this.countryCode}"],"profile":"${this.profileName}"}},{"name":"neither","type":"bar","query":{"name":"new.oso.publications.green_gold.peer_reviewed.affiliated.byfunder.country","parameters":[0,0,"${this.countryCode}"],"profile":"${this.profileName}"}}],"chart":{"backgroundColor":"#FFFFFFFF","borderColor":"#335cadff","borderRadius":0,"borderWidth":0,"plotBorderColor":"#ccccccff","plotBorderWidth":0},"title":{"text":"Gold vs Green Open Access publications","align":"left","margin":50},"subtitle":{"text":"by funder (top funders)","align":"left"},"yAxis":{"title":{"text":""},"reversedStacks":false},"xAxis":{"title":{"text":""}},"lang":{"noData":"No Data available for the Query"},"exporting":{"enabled":true},"plotOptions":{"series":{"dataLabels":{"enabled":false},"stacking":"normal"}},"legend":{"enabled":true},"credits":{"href":null,"enabled":false},"colors":[\"${this.goldGreenIndicatorsPalette.join('","')}\"]}}`));
    }
  }
}
